Crate auto_bench_fct_macros

Crate auto_bench_fct_macros 

Attribute Macros

auto_bench_fct
Add the #[auto_bench_fct] macro attribute to a function to enable automatic benchmarking. It will store in a map the number of calls and the total duration of the function execution.
auto_bench_fct_hy
Add the #[auto_bench_fct_hy] macro attribute to a function to enable automatic benchmarking with hierarchy computation. It will do the same as #[auto_bench_fct], but it will also track he call stack, allowing to display the hierarchy of function calls.